/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.atlas.adls.bridge.models;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonSerialize(include=JsonSerialize.Inclusion.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
@XmlRootElement
@XmlAccessorType(XmlAccessType.PROPERTY)
public class IDBrokerAzureCredential implements Serializable {
    private static final long serialVersionUID = 1L;

    @JsonProperty("access_token")
    private String access_token;

    @JsonProperty("client_id")
    private String client_id;

    @JsonProperty("expires_in")
    private Long expires_in;

    @JsonProperty("expires_on")
    private Long expires_on;

    @JsonProperty("ext_expires_in")
    private Long ext_expires_in;

    @JsonProperty("not_before")
    private Long not_before;

    @JsonProperty("resource")
    private String resource;

    @JsonProperty("token_type")
    private String token_type;

    @JsonIgnore
    private Map<String, Object> additionalProperties;

    public IDBrokerAzureCredential() {
        this.additionalProperties = new HashMap<String, Object>();
    }

    @JsonProperty("access_token")
    public String getAccess_token() {
        return this.access_token;
    }

    @JsonProperty("access_token")
    public void setAccess_token(String access_token) {
        this.access_token = access_token;
    }

    @JsonProperty("client_id")
    public String getClient_id() {
        return this.client_id;
    }

    @JsonProperty("client_id")
    public void setClient_id(String client_id) {
        this.client_id = client_id;
    }

    @JsonProperty("expires_in")
    public Long getExpires_in() {
        return this.expires_in;
    }

    @JsonProperty("expires_in")
    public void setExpires_in(Long expires_in) {
        this.expires_in = expires_in;
    }

    @JsonProperty("expires_on")
    public Long getExpires_on() {
        return this.expires_on;
    }

    @JsonProperty("expires_on")
    public void setExpires_on(Long expires_on) {
        this.expires_on = expires_on;
    }

    @JsonProperty("ext_expires_in")
    public Long getExt_expires_in() {
        return this.ext_expires_in;
    }

    @JsonProperty("ext_expires_in")
    public void setExt_expires_in(Long ext_expires_in) {
        this.ext_expires_in = ext_expires_in;
    }

    @JsonProperty("not_before")
    public Long getNot_before() {
        return this.not_before;
    }

    @JsonProperty("not_before")
    public void setNot_before(Long not_before) {
        this.not_before = not_before;
    }

    @JsonProperty("resource")
    public String getResource() {
        return this.resource;
    }

    @JsonProperty("resource")
    public void setResource(String resource) {
        this.resource = resource;
    }

    @JsonProperty("token_type")
    public String getToken_type() {
        return this.token_type;
    }

    @JsonProperty("token_type")
    public void setToken_type(String token_type) {
        this.token_type = token_type;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }
}